pub struct IPR(/* private fields */);Expand description
Internal Path Representation.
They obey the following rules:
- Valid UTF-8
- Are path-separated with /
- Do not begin or end with /
- Do not contain . or .. segments
- Do not contain multiple / characters right next to each other
We can actually infallibly convert to these constraints as long as the input we’re working with is already UTF-8, which Rust strings are! It’s worthwhile to note that this is actually much pickier in certain ways than actual UNIX paths, and you may find some imports fail when dealing with non-unicode paths. The official dirtabase/ark policy for these situations is “we aren’t making stuff for your use case.”
Implementations
Sourceimpl IPR
impl IPR
Sourcepub fn is_well_formed(src: &str) -> bool
pub fn is_well_formed(src: &str) -> bool
Quick check to see if a string already meets requirements.
Sourcepub fn canonize<'a>(src: &'a str) -> Cow<'a, str>
pub fn canonize<'a>(src: &'a str) -> Cow<'a, str>
Produce a &str in IPR form.
Reuses original string if it’s already suitable. Hence the Cow.
Sourcepub fn force_canonize(src: &str) -> String
pub fn force_canonize(src: &str) -> String
Produce an owned String in IPR form.
Doesn’t short-circuit to reuse existing memory. Just always charges forward with a statically compiled regex and gets ’er done.